mercurial/lock.py
changeset 28027 14033c5dd261
parent 27797 054abf2377e8
child 28959 518c3e392f75
--- a/mercurial/lock.py	Mon Feb 08 00:47:36 2016 +0000
+++ b/mercurial/lock.py	Wed Feb 03 09:11:22 2016 +0000
@@ -9,7 +9,6 @@
 
 import contextlib
 import errno
-import os
 import socket
 import time
 import warnings
@@ -77,8 +76,8 @@
         self.release()
 
     def _getpid(self):
-        # wrapper around os.getpid() to make testing easier
-        return os.getpid()
+        # wrapper around util.getpid() to make testing easier
+        return util.getpid()
 
     def lock(self):
         timeout = self.timeout